==> spicyR_1.10.3.tar.gz: spicyR/inst/doc/spicyR.R <==
params <-
list(test = FALSE)

## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(BiocStyle)

## ----warning=FALSE, message=FALSE---------------------------------------------
# load required packages
library(spicyR)
library(ggplot2)

## ---- eval = FALSE------------------------------------------------------------
#  if (!require("BiocManager"))
#      install.packages("BiocManager")
#  BiocManager::install("spicyR")

## -----------------------------------------------------------------------------
data("diabetesData")
diabetesData
cellSummary(diabetesData)
imagePheno(diabetesData)

## ----message=FALSE------------------------------------------------------------
spicyTestPair <- spicy(diabetesData,
                       condition = "stage",
                       subject = "case",
                       from = "beta",
                       to = "delta")

topPairs(spicyTestPair)

## ----eval=FALSE---------------------------------------------------------------
#  spicyTest <- spicy(diabetesData,
#                     condition = "stage",
#                     subject = "case")

## -----------------------------------------------------------------------------
data("spicyTest")

## -----------------------------------------------------------------------------
spicyTest
topPairs(spicyTest)  

## -----------------------------------------------------------------------------
signifPlot(spicyTest, 
           breaks=c(-3, 3, 1),
           marksToPlot = c("alpha", "beta", "gamma", "delta", 
                           "B", "naiveTc", "Th", "Tc", "neutrophil", "macrophage"))

## -----------------------------------------------------------------------------
sessionInfo()

==> spicyR_1.10.4.tar.gz: spicyR/inst/doc/spicyR.R <==
params <-
list(test = FALSE)

## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(BiocStyle)

## ----warning=FALSE, message=FALSE---------------------------------------------
# load required packages
library(spicyR)
library(ggplot2)
library(SingleCellExperiment)

## ---- eval = FALSE------------------------------------------------------------
#  if (!require("BiocManager"))
#      install.packages("BiocManager")
#  BiocManager::install("spicyR")

## -----------------------------------------------------------------------------
data("diabetesData_SCE")
diabetesData_SCE

## ----message=FALSE------------------------------------------------------------
spicyTestPair <- spicy(diabetesData,
                       condition = "stage",
                       subject = "case",
                       from = "beta",
                       to = "delta")

topPairs(spicyTestPair)

## ----eval=FALSE---------------------------------------------------------------
#  spicyTest <- spicy(diabetesData_SCE,
#                     condition = "stage",
#                     subject = "case")

## -----------------------------------------------------------------------------
data("spicyTest")

## -----------------------------------------------------------------------------
spicyTest
topPairs(spicyTest)  

## -----------------------------------------------------------------------------
signifPlot(spicyTest, 
           breaks=c(-3, 3, 1),
           marksToPlot = c("alpha", "beta", "gamma", "delta", 
                           "B", "naiveTc", "Th", "Tc", "neutrophil", "macrophage"))

## -----------------------------------------------------------------------------
sessionInfo()
